==> libcamera-docs-0.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/search/all_19.js <==
var searchData=
[
  ['y_0',['y',['../classlibcamera_1_1Point.html#a02e6dd3f6d964e480e9f9acb07005f86',1,'libcamera::Point::y'],['../classlibcamera_1_1Rectangle.html#ac18afa68818e0af57adc858b37d2c665',1,'libcamera::Rectangle::y'],['../classlibcamera_1_1ipa_1_1Vector.html#a9ed2979fa465971b421aa4d5df66ea46',1,'libcamera::ipa::Vector::y() const'],['../classlibcamera_1_1ipa_1_1Vector.html#aaa345d73db6776edaf878ef69459f853',1,'libcamera::ipa::Vector::y()']]],
  ['yaml_5fparser_2eh_1',['yaml_parser.h',['../yaml__parser_8h.html',1,'']]],
  ['yamlobject_2',['YamlObject',['../classlibcamera_1_1YamlObject.html',1,'libcamera']]],
  ['yamlparser_3',['YamlParser',['../classlibcamera_1_1YamlParser.html',1,'libcamera']]],
  ['ycbcrencoding_4',['YcbcrEncoding',['../classlibcamera_1_1ColorSpace.html#a6c38886cf640948d04502d365d9e0ec9',1,'libcamera::ColorSpace']]],
  ['ycbcrencoding_5',['ycbcrEncoding',['../classlibcamera_1_1ColorSpace.html#a55c36dc1d34535b71bf2990eb7139e99',1,'libcamera::ColorSpace']]],
  ['yeveninc_6',['yEvenInc',['../classlibcamera_1_1SensorConfiguration.html#a4210adfa9239cb2b368132537d84665a',1,'libcamera::SensorConfiguration']]],
  ['yhistogram_7',['yHistogram',['../structlibcamera_1_1SwIspStats.html#a873420e49e5b6aa4f544258f14467144',1,'libcamera::SwIspStats']]],
  ['yoddinc_8',['yOddInc',['../classlibcamera_1_1SensorConfiguration.html#acc4e3c6d05cb1b8439f539690318021b',1,'libcamera::SensorConfiguration']]],
  ['ytarget_9',['yTarget',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a20a54a23afacf386dbb99f958ceb53a4',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]]
];

==> libcamera-docs-0.5.1-2-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/search/all_19.js <==
var searchData=
[
  ['y_0',['y',['../classlibcamera_1_1Point.html#a02e6dd3f6d964e480e9f9acb07005f86',1,'libcamera::Point::y'],['../classlibcamera_1_1Rectangle.html#ac18afa68818e0af57adc858b37d2c665',1,'libcamera::Rectangle::y'],['../classlibcamera_1_1Vector.html#a4e3332fc4259eaa783f1cc168c5cb2ad',1,'libcamera::Vector::y() const'],['../classlibcamera_1_1Vector.html#aa5ba480f8b3e71ad8e81afb03d976ba7',1,'libcamera::Vector::y()']]],
  ['yaml_5fparser_2eh_1',['yaml_parser.h',['../yaml__parser_8h.html',1,'']]],
  ['yamlobject_2',['YamlObject',['../classlibcamera_1_1YamlObject.html',1,'libcamera']]],
  ['yamlparser_3',['YamlParser',['../classlibcamera_1_1YamlParser.html',1,'libcamera']]],
  ['ycbcrencoding_4',['YcbcrEncoding',['../classlibcamera_1_1ColorSpace.html#a6c38886cf640948d04502d365d9e0ec9',1,'libcamera::ColorSpace']]],
  ['ycbcrencoding_5',['ycbcrEncoding',['../classlibcamera_1_1ColorSpace.html#a55c36dc1d34535b71bf2990eb7139e99',1,'libcamera::ColorSpace']]],
  ['yeveninc_6',['yEvenInc',['../classlibcamera_1_1SensorConfiguration.html#a4210adfa9239cb2b368132537d84665a',1,'libcamera::SensorConfiguration']]],
  ['yhistogram_7',['yHistogram',['../structlibcamera_1_1SwIspStats.html#a873420e49e5b6aa4f544258f14467144',1,'libcamera::SwIspStats']]],
  ['yoddinc_8',['yOddInc',['../classlibcamera_1_1SensorConfiguration.html#acc4e3c6d05cb1b8439f539690318021b',1,'libcamera::SensorConfiguration']]],
  ['ytarget_9',['yTarget',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a20a54a23afacf386dbb99f958ceb53a4',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]]
];
